@@ -10,45 +10,45 @@ const expect = chai.expect;
 
 chai.config.includeStack = true;
 
-describe('Mime-Funcs Tests', function() {
-    describe('#isPlainText', function() {
-        it('should detect plain text', function() {
+describe('Mime-Funcs Tests', function () {
+    describe('#isPlainText', function () {
+        it('should detect plain text', function () {
             expect(mimeFuncs.isPlainText('abc')).to.be.true;
             expect(mimeFuncs.isPlainText('abc\x02')).to.be.false;
             expect(mimeFuncs.isPlainText('abcõ')).to.be.false;
         });
-        it('should return true', function() {
+        it('should return true', function () {
             expect(mimeFuncs.isPlainText('az09\t\r\n~!?')).to.be.true;
         });
 
-        it('should return false on low bits', function() {
+        it('should return false on low bits', function () {
             expect(mimeFuncs.isPlainText('az09\n\x08!?')).to.be.false;
         });
 
-        it('should return false on high bits', function() {
+        it('should return false on high bits', function () {
             expect(mimeFuncs.isPlainText('az09\nõ!?')).to.be.false;
         });
     });
 
-    describe('#hasLongerLines', function() {
-        it('should detect longer lines', function() {
+    describe('#hasLongerLines', function () {
+        it('should detect longer lines', function () {
             expect(mimeFuncs.hasLongerLines('abc\ndef', 5)).to.be.false;
             expect(mimeFuncs.hasLongerLines('juf\nabcdef\nghi', 5)).to.be.true;
         });
     });
 
-    describe('#encodeWord', function() {
-        it('should encode quoted-printable', function() {
+    describe('#encodeWord', function () {
+        it('should encode quoted-printable', function () {
             expect('=?UTF-8?Q?See_on_=C3=B5hin_test?=').to.equal(mimeFuncs.encodeWord('See on õhin test'));
         });
 
-        it('should encode base64', function() {
+        it('should encode base64', function () {
             expect('=?UTF-8?B?U2VlIG9uIMO1aGluIHRlc3Q=?=').to.equal(mimeFuncs.encodeWord('See on õhin test', 'B'));
         });
     });
 
-    describe('#encodeWords', function() {
-        it('should encode Ascii range', function() {
+    describe('#encodeWords', function () {
+        it('should encode Ascii range', function () {
             let input1 = 'метель" вьюга',
                 input2 = 'метель\x27вьюга',
                 input3 = 'Verão você vai adorar!',
@@ -63,7 +63,7 @@ describe('Mime-Funcs Tests', function() {
             expect(mimeFuncs.encodeWords(input3, 'Q', 52, true)).to.equal(output4);
         });
 
-        it('should split QP on maxLength', function() {
+        it('should split QP on maxLength', function () {
             let inputStr = 'Jõgeva Jõgeva Jõgeva mugeva Jõgeva Jõgeva Jõgeva Jõgeva Jõgeva',
                 outputStr =
                     '=?UTF-8?Q?J=C3=B5geva_?= =?UTF-8?Q?J=C3=B5geva_?= =?UTF-8?Q?J=C3=B5geva_?= =?UTF-8?Q?mugeva_J?= =?UTF-8?Q?=C3=B5geva_J?= =?UTF-8?Q?=C3=B5geva_J?= =?UTF-8?Q?=C3=B5geva_J?= =?UTF-8?Q?=C3=B5geva_J?= =?UTF-8?Q?=C3=B5geva?=',
@@ -73,7 +73,7 @@ describe('Mime-Funcs Tests', function() {
             expect(inputStr).to.equal(libmime.decodeWords(encoded));
         });
 
-        it('should split base64 on maxLength', function() {
+        it('should split base64 on maxLength', function () {
             let inputStr = 'õõõõõ õõõõõ õõõõõ mugeva õõõõõ õõõõõ õõõõõ õõõõõ Jõgeva',
                 outputStr =
                     '=?UTF-8?B?w7XDtcO1w7XDtSA=?= =?UTF-8?B?w7XDtcO1w7XDtSA=?= =?UTF-8?B?w7XDtcO1w7XDtSBt?= =?UTF-8?B?dWdldmEgw7XDtcO1?= =?UTF-8?B?w7XDtSDDtcO1w7U=?= =?UTF-8?B?w7XDtSDDtcO1w7U=?= =?UTF-8?B?w7XDtSDDtcO1w7U=?= =?UTF-8?B?w7XDtSBKw7VnZXZh?=',
@@ -84,8 +84,8 @@ describe('Mime-Funcs Tests', function() {
         });
     });
 
-    describe('#buildHeaderParam', function() {
-        it('should return unmodified', function() {
+    describe('#buildHeaderParam', function () {
+        it('should return unmodified', function () {
             expect([
                 {
                     key: 'title',
@@ -94,7 +94,7 @@ describe('Mime-Funcs Tests', function() {
             ]).to.deep.equal(mimeFuncs.buildHeaderParam('title', 'this is just a title', 500));
         });
 
-        it('should encode and split ascii', function() {
+        it('should encode and split ascii', function () {
             expect([
                 {
                     key: 'title*0',
@@ -115,7 +115,7 @@ describe('Mime-Funcs Tests', function() {
             ]).to.deep.equal(mimeFuncs.buildHeaderParam('title', 'this is just a title', 5));
         });
 
-        it('should encode double byte unicode characters', function() {
+        it('should encode double byte unicode characters', function () {
             expect([
                 {
                     key: 'title*0*',
@@ -124,7 +124,7 @@ describe('Mime-Funcs Tests', function() {
             ]).to.deep.equal(mimeFuncs.buildHeaderParam('title', 'Unicode title 😊', 50));
         });
 
-        it('should encode and split unicode', function() {
+        it('should encode and split unicode', function () {
             expect([
                 {
                     key: 'title*0*',
@@ -145,7 +145,7 @@ describe('Mime-Funcs Tests', function() {
             ]).to.deep.equal(mimeFuncs.buildHeaderParam('title', 'this is just a title õäöü', 20));
         });
 
-        it('should encode and split filename with dashes', function() {
+        it('should encode and split filename with dashes', function () {
             expect([
                 {
                     key: 'filename*0*',
@@ -158,14 +158,14 @@ describe('Mime-Funcs Tests', function() {
             ]).to.deep.equal(mimeFuncs.buildHeaderParam('filename', 'Ɣ------Ɣ------Ɣ------Ɣ------Ɣ------Ɣ------Ɣ------.pdf', 50));
         });
 
-        it('should encode and decode', function() {
+        it('should encode and decode', function () {
             let input =
                 'Lorěm ipsum doloř siť amet, háš peřpetua compřéhenšam at, ei nám modó soleát éxpétěndá! Boňorum vocibůs dignisšim pro ad, ea sensibus efficiendi intellegam ius. Ad nam aperiam delicata voluptaria, vix nobis luptatum ea, ců úsú graeco viďiššě ňusqúam. ';
             let headerLine =
                 'content-disposition: attachment; ' +
                 mimeFuncs
                     .buildHeaderParam('filename', input, 50)
-                    .map(function(item) {
+                    .map(function (item) {
                         return item.key + '="' + item.value + '"';
                     })
                     .join('; ');
@@ -174,8 +174,8 @@ describe('Mime-Funcs Tests', function() {
         });
     });
 
-    describe('#parseHeaderValue', function() {
-        it('should handle default value only', function() {
+    describe('#parseHeaderValue', function () {
+        it('should handle default value only', function () {
             let str = 'text/plain',
                 obj = {
                     value: 'text/plain',
@@ -185,7 +185,7 @@ describe('Mime-Funcs Tests', function() {
             expect(mimeFuncs.parseHeaderValue(str)).to.deep.equal(obj);
         });
 
-        it('should handle unquoted params', function() {
+        it('should handle unquoted params', function () {
             let str = 'text/plain; CHARSET= UTF-8; format=flowed;',
                 obj = {
                     value: 'text/plain',
@@ -198,7 +198,7 @@ describe('Mime-Funcs Tests', function() {
             expect(mimeFuncs.parseHeaderValue(str)).to.deep.equal(obj);
         });
 
-        it('should handle quoted params', function() {
+        it('should handle quoted params', function () {
             let str = 'text/plain; filename= ";;;\\""; format=flowed;',
                 obj = {
                     value: 'text/plain',
@@ -211,7 +211,7 @@ describe('Mime-Funcs Tests', function() {
             expect(mimeFuncs.parseHeaderValue(str)).to.deep.equal(obj);
         });
 
-        it('should handle multi line values', function() {
+        it('should handle multi line values', function () {
             let str =
                     'text/plain; single_encoded*="UTF-8\'\'%C3%95%C3%84%C3%96%C3%9C";\n' +
                     ' multi_encoded*0*=UTF-8\x27\x27%C3%96%C3%9C;\n' +
@@ -232,7 +232,7 @@ describe('Mime-Funcs Tests', function() {
             expect(mimeFuncs.parseHeaderValue(str)).to.deep.equal(obj);
         });
 
-        it('should handle params only', function() {
+        it('should handle params only', function () {
             let str = '; CHARSET= UTF-8; format=flowed;',
                 obj = {
                     value: '',
@@ -246,8 +246,8 @@ describe('Mime-Funcs Tests', function() {
         });
     });
 
-    describe('#_buildHeaderValue', function() {
-        it('should build header value', function() {
+    describe('#_buildHeaderValue', function () {
+        it('should build header value', function () {
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test'
@@ -276,7 +276,7 @@ describe('Mime-Funcs Tests', function() {
                         a: ';"'
                     }
                 })
-            ).to.equal('test; a=";\\""');
+            ).to.equal("test; a*0*=utf-8''%3B%22");
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test',
@@ -288,7 +288,7 @@ describe('Mime-Funcs Tests', function() {
             ).to.equal('test; a=b; c=d');
         });
 
-        it('should handle unicode filename', function() {
+        it('should handle unicode filename', function () {
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test',
@@ -302,7 +302,7 @@ describe('Mime-Funcs Tests', function() {
             );
         });
 
-        it('should handle dashed filename', function() {
+        it('should handle dashed filename', function () {
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test',
@@ -313,7 +313,7 @@ describe('Mime-Funcs Tests', function() {
             ).to.equal('test; filename*0*=utf-8\x27\x27%C6%94------%C6%94------%C6%94------%C6%94; filename*1*=------%C6%94------%C6%94------%C6%94------.pdf');
         });
 
-        it('should split emoji filename', function() {
+        it('should split emoji filename', function () {
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test',
@@ -325,7 +325,7 @@ describe('Mime-Funcs Tests', function() {
             ).to.equal('test; a=b; filename*0*=utf-8\x27\x27J%C3%B5ge-va%C5%BDJ%C3%B5ge-va%C5%BDJ; filename*1*=%C3%B5ge-va%C5%BD.pdf');
         });
 
-        it('should quote filename with spaces', function() {
+        it('should quote filename with spaces', function () {
             expect(
                 mimeFuncs.buildHeaderValue({
                     value: 'test',
@@ -338,7 +338,7 @@ describe('Mime-Funcs Tests', function() {
 
         // For exhaustive list of special characters
         // Refer: https://www.w3.org/Protocols/rfc1341/4_Content-Type.html
-        it('should quote filename with special characters', function() {
+        it('should quote filename with special characters', function () {
             // The case of browser downloads when we download multiple files with same name.
             expect(
                 mimeFuncs.buildHeaderValue({
@@ -371,7 +371,7 @@ describe('Mime-Funcs Tests', function() {
                 'colon="x:y"',
                 'back_slash="x\\\\y"',
                 'single_quote="x\'y"',
-                'double_quotes="x\\"y"',
+                "double_quotes*0*=utf-8''x%22y",
                 'forward_slash="x/y"',
                 'big_bracket_open="x[y"',
                 'big_bracket_close="x]y"',
@@ -411,8 +411,8 @@ describe('Mime-Funcs Tests', function() {
         });
     });
 
-    describe('#foldLines', function() {
-        it('should Fold long header line', function() {
+    describe('#foldLines', function () {
+        it('should Fold long header line', function () {
             let inputStr = 'Subject: Testin command line kirja õkva kakva mõni tõnis kõllas põllas tõllas rõllas jušla kušla tušla musla',
                 outputStr =
                     'Subject: Testin command line kirja\r\n' +
@@ -424,7 +424,7 @@ describe('Mime-Funcs Tests', function() {
             expect(outputStr).to.equal(mimeFuncs.foldLines(encodedHeaderLine, 76));
         });
 
-        it('should Fold flowed text', function() {
+        it('should Fold flowed text', function () {
             let inputStr =
                     'Testin command line kirja õkva kakva mõni tõnis kõllas põllas tõllas rõllas jušla kušla tušla musla Testin command line kirja õkva kakva mõni tõnis kõllas põllas tõllas rõllas jušla kušla tušla musla',
                 outputStr =
@@ -435,7 +435,7 @@ describe('Mime-Funcs Tests', function() {
             expect(outputStr).to.equal(mimeFuncs.foldLines(inputStr, 76, true));
         });
 
-        it('should fold one long line', function() {
+        it('should fold one long line', function () {
             let inputStr =
                     'Subject: =?UTF-8?Q?=CB=86=C2=B8=C3=81=C3=8C=C3=93=C4=B1=C3=8F=CB=87=C3=81=C3=9B^=C2=B8\\=C3=81=C4=B1=CB=86=C3=8C=C3=81=C3=9B=C3=98^\\=CB=9C=C3=9B=CB=9D=E2=84=A2=CB=87=C4=B1=C3=93=C2=B8^\\=CB=9C=EF=AC=81^\\=C2=B7\\=CB=9C=C3=98^=C2=A3=CB=9C#=EF=AC=81^\\=C2=A3=EF=AC=81^\\=C2=A3=EF=AC=81^\\?=',
                 outputStr =
